__author__  = "Marco Musy"
__email__   = "marco.musy@gmail.com"
__version__ = "2.0.5" # defined in setup.py and README.md
__status__  = "dev"
__website__ = "https://github.com/marcomusy/pianoplayer"
__license__ = "MIT" 
